==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/input/validators/HostnameOrIPAddressWithPortValidator.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.input.validators;
 
/**
 * A validator for hostname / ipaddress and port strings in the format
 * <i>hostname[:port]</i> or <i>ipAddress[:port]</i>.  
 * 
 * @author Brett Smith <a href="mailto: brett@3sp.com">&lt;brett@3sp.com&gt;</a>
 */
public class HostnameOrIPAddressWithPortValidator extends StringValidator {
	
	/**
	 * Regular expression for a string in the format <i>hostname[:port]</i> or
	 * <i>ipAddress[:port]</i>.
	 */
	final static String HOST_PATTERN = "^[a-zA-Z0-9\\.\\-]*((\\:[0-9]*)?)$";

	/**
	 * Constructor.
	 */
	public HostnameOrIPAddressWithPortValidator() {
		super(1, 255, HOST_PATTERN, null, true); 
		this.regExpErrCode = ErrorConstants.ERR_STRING_ISNT_HOSTNAME_OR_IPADDRESS_WITH_PORT;
	}

    
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/input/validators/HostnameOrIPAddressWithPortValidator.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.input.validators;

import java.util.regex.Pattern;
 
/**
 * A validator for hostname / ipaddress and port strings in the format
 * <i>hostname[:port]</i> or <i>ipAddress[:port]</i>.  
 * 
 * @author Brett Smith <a href="mailto: brett@3sp.com">&lt;brett@3sp.com&gt;</a>
 */
public class HostnameOrIPAddressWithPortValidator extends StringValidator {
	
	private static final int MAX_HOST_OR_IP_CHARS = 255;
    /**
	 * Regular expression for a string in the format <i>hostname[:port]</i> or
	 * <i>ipAddress[:port]</i>.
	 */
	final static String HOST_PATTERN = "^[a-zA-Z0-9\\.\\-\\_]*((\\:[0-9]*)?)$";

	/**
	 * Constructor.
	 */
	public HostnameOrIPAddressWithPortValidator() {
		super(1, MAX_HOST_OR_IP_CHARS, HOST_PATTERN, null, true); 
		this.regExpErrCode = ErrorConstants.ERR_STRING_ISNT_HOSTNAME_OR_IPADDRESS_WITH_PORT;
	}

    /**
     * Static method which validates a host or IP.
     * 
     * @param value
     * @return boolean
     */
    public static boolean isValidAsHostOrIp(String value){
        if (value.length() > MAX_HOST_OR_IP_CHARS)
            return false;
        else
            return Pattern.compile(HOST_PATTERN).matcher(value).matches();
    }

}
